@@ -43,7 +43,7 @@ freely, subject to the following restrictions:
 #define CGNSLIB_KEYWORDS_H
 
 /*
-   THIS HEADER CAN BE READ BY ANY C LANGAGE PRE-PROCESSOR
+   THIS HEADER CAN BE READ BY ANY C LANGUAGE PRE-PROCESSOR
 
    ENUMERATES DEFINITIONS ARE DECLARED, IN THE CASE YOU DO NOT WANT
    THESE DEFINITIONS (e.g. you compile Fortran) THEN YOU HAVE TO UNSET
@@ -63,8 +63,8 @@ freely, subject to the following restrictions:
  *      VERSION NUMBER                                                   *
 \* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-#define CGNS_VERSION 3130
-#define CGNS_DOTVERS 3.13
+#define CGNS_VERSION 4200
+#define CGNS_DOTVERS 4.20
 #define CGNS_COMPATVERSION 2540
 #define CGNS_COMPATDOTVERS 2.54
 
@@ -79,7 +79,6 @@ freely, subject to the following restrictions:
 #define CG_MODE_READ	0
 #define CG_MODE_WRITE	1
 #define CG_MODE_MODIFY	2
-#define CG_MODE_CLOSED	3
 
 /* function return codes */
 
@@ -339,7 +338,7 @@ typedef enum {
 #define NSTurbulentIncompressible_s    "NSTurbulentIncompressible"
 
 /* Any model type will accept both ModelTypeNull and ModelTypeUserDefined.
-** The following models will accept these values as vaild...
+** The following models will accept these values as valid...
 **
 ** GasModel_t: Ideal, VanderWaals, CaloricallyPerfect, ThermallyPerfect,
 **    ConstantDensity, RedlichKwong
@@ -477,16 +476,18 @@ typedef enum {
 #ifdef __CGNS_ENUMS__
 typedef enum {
 	DataTypeNull, DataTypeUserDefined, Integer, RealSingle,
-	RealDouble, Character, LongInteger
+	RealDouble, Character, LongInteger, ComplexSingle, ComplexDouble
 } DataType_t;
 #endif
-#define NofValidDataTypes 7
+#define NofValidDataTypes 9
 
 #define Integer_s                      "Integer"
 #define RealSingle_s                   "RealSingle"
 #define RealDouble_s                   "RealDouble"
 #define Character_s                    "Character"
 #define LongInteger_s                  "LongInteger"
+#define ComplexSingle_s                "ComplexSingle"
+#define ComplexDouble_s                "ComplexDouble"
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - *\
  *      Element types                                                    *
